.. include global.rst

``GValue``
==========

This module defines the pyvips ``GValue`` class. You can use instances of
this class to get and set :class:`.GObject` properties. 

.. automodule:: pyvips.gvalue
        :members:

